@@ -88,7 +88,7 @@ class arguments {
         $args["pplace"]=array();
 
         /*
-          Used short arguments: A C D H I N P V a c d f h i l n p r t u v w
+          Used short arguments: A C D H I N P V a c d f g h i l n p r t u v w
         */
         $size=sizeof($argv);
         for ($i=0; $i<$size; $i++) {
@@ -138,6 +138,7 @@ class arguments {
                 }
                 break;
             case "--dumpconfig":
+            case "--dump-config":
                 static::$command="dumpconfig";
                 break;
             case "--fields":
@@ -145,6 +146,12 @@ class arguments {
             case "-f":
                 $args["fields"][]=$argv[++$i];
                 break;
+            case "--getconfig":
+            case "--get-config":
+            case "-g":
+                static::$command="getconfig";
+                $args["_getconfigitem"]=$argv[++$i];
+                break;
             case "--import":
                 static::$command="import";
                 break;
@@ -494,6 +501,7 @@ class arguments {
             case "_configitem":
             case "_configvalue":
             case "_configdefault":
+            case "_getconfigitem":
                 $vars[$type]=$arg;
                 break;
             }
