@@ -95,6 +95,9 @@ class cli {
         case "config":
             $this->doConfig();
             break;
+        case "getconfig":
+            $this->doGetConfig();
+            break;
         case "dumpconfig":
             $this->doDumpConfig();
             break;
@@ -371,19 +374,25 @@ class cli {
         $item->update();
     }
 
+    /**
+     * Process --getconfig
+     */
+    private function doGetConfig() {
+        $vars=$this->args->getVars();
+        $name=$vars["_getconfigitem"];
+        $item=conf::getItemByName($name);
+        echo $item->displayValue() . "\n";
+
+    }
+
     /**
      * Process --dump-config
      */
     private function doDumpConfig() {
         $conf=conf::getAll();
         foreach ($conf as $item) {
-            foreach ($item as $citem) {
-                if ($citem instanceof \conf\item\checkbox) {
-                    $value=($citem->getValue() ? "true": "false");
-                } else {
-                    $value=$citem->getValue();
-                }
-                echo $citem->getName() . ": " . $value . "\n";
+            foreach ($item->getItems() as $citem) {
+                echo $citem->getName() . ": " . $citem->displayValue() . "\n";
             }
         }
     }
