@@ -23,6 +23,7 @@ namespace import;
 use file;
 use log;
 use photo;
+use category;
 use settings;
 
 use conf\conf;
@@ -79,7 +80,7 @@ abstract class base {
             $path="";
         }
 
-        foreach ($files as $file) {
+        foreach ($files as $md5 => $file) {
             static::progress($cur, $total);
             $cur++;
 
@@ -160,6 +161,17 @@ abstract class base {
                 if (isset($rating)) {
                     $photo->rate($rating);
                 }
+
+                if (strlen($md5) > 10) {
+                    $counter = 0;
+                    $categories = $vars["_category_" . $md5 ] ?? false;
+                    if (is_array($categories)) {
+                        foreach ($categories as $category) {
+                            $photo->addTo(new category($category));
+                        }
+                    }
+                }
+
                 if (conf::get("import.cli.hash")===true) {
                     try {
                         $photo->getHash();
