@@ -29,6 +29,8 @@ use conf\conf;
 
 use template\template;
 
+use xmp\reader as xmpreader;
+
 /**
  * This class holds all the functions for uploading and importing images
  * to Zoph via the web interface.
@@ -411,6 +413,9 @@ class web extends base {
                 if (file_exists($dir . DIRECTORY_SEPARATOR . $thumb) &&
                   file_exists($dir . DIRECTORY_SEPARATOR . $mid)) {
                     $status="done";
+                    $xmp = new xmpreader($file);
+                    $data=$xmp->getXMP()[0];
+                    $subject = (array) $data->getRDFDescription("dc:subject");
                 } else {
                     $icon=template::getImage("icons/pause.png");
                     $status="waiting";
@@ -443,6 +448,15 @@ class web extends base {
                 $xmlstatus=$xml->createElement("status", $status);
                 $xmlfile->appendChild($xmlstatus);
             }
+
+            if (is_array($subject) && sizeof($subject) > 0) {
+                $xmlsubjects=$xml->createElement("subjects");
+                foreach($subject as $subj) {
+                    $xmlsubjects->appendChild($xml->createElement("subject", $subj));
+                }
+                $xmlfile->appendChild($xmlsubjects);
+            }
+
             $root->appendChild($xmlfile);
         }
         $xml->appendChild($root);
@@ -493,7 +507,7 @@ class web extends base {
         foreach ($import as $md5) {
             $file=file::getFromMD5(conf::get("path.images") . "/" . conf::get("path.upload"), $md5);
             if (!empty($file)) {
-                $files[]=$file;
+                $files[$md5]=$file;
             }
         }
         if (is_array($files)) {
