@@ -24,6 +24,7 @@
 
 use db\db;
 use db\select;
+use db\update;
 use db\param;
 use db\clause;
 use db\selectHelper;
@@ -84,7 +85,7 @@ class photo extends zophTable {
     *               string jpeg: the jpeg file
     * @todo only supports JPEG currently, should support more filetypes
     */
-    public function display($type=null) {
+    public function display($type = null) {
         $header=array();
         $name = $this->get("name");
         $image_path = conf::get("path.images") . "/" . $this->get("path") . "/";
@@ -335,26 +336,13 @@ class photo extends zophTable {
      */
     public function updateEXIF() {
         $file=$this->getFilePath();
-        $exif=process_exif ($file);
+        $exif=process_exif($file);
         if ($exif) {
             $this->setFields($exif);
             $this->update();
         }
     }
 
-    /**
-     * Gets last used position for people on a photo
-     * @return int position
-     */
-    public function getLastPersonPos() {
-        $qry=new select(array("pp" => "photo_people"));
-        $qry->addFunction(array("pos" => "max(position)"));
-        $qry->where(new clause("photo_id=:photoid"));
-        $qry->addParam(new param(":photoid", (int) $this->getId(), PDO::PARAM_INT));
-        $result=db::query($qry)->fetch(PDO::FETCH_ASSOC);
-        return (int) $result["pos"];
-    }
-
     /**
      * Get the file name of this photo
      * @return string file name
@@ -439,41 +427,6 @@ class photo extends zophTable {
         return category::getRecordsFromQuery($qry);
     }
 
-    /**
-     * Get a list of people on this photo
-     * @return array of people
-     */
-    public function getPeople() {
-        $qry=new select(array("p" => "people"));
-        $qry->join(array("pp" => "photo_people"), "pp.person_id = p.person_id");
-        $distinct=true;
-        $qry->addFields(array("person_id"), $distinct);
-        $qry->addFields(array("last_name", "first_name", "called", "pp.position"));
-
-        $where=new clause("pp.photo_id=:photoid");
-
-        $qry->addParam(new param(":photoid", (int) $this->getId(), PDO::PARAM_INT));
-        $qry->addOrder("pp.position");
-        $qry->where($where);
-
-        return person::getRecordsFromQuery($qry);
-    }
-
-    /**
-     * Get links to the people appearing on this photo
-     * @return string
-     */
-    public function getPeopleLinks() {
-        $people = $this->getPeople();
-        $links=array();
-        if ($people) {
-            foreach ($people as $person) {
-                $links[]=$person->getLink(0);
-            }
-        }
-        return $links;
-    }
-
     /**
      * Import a file into the database
      *
@@ -563,7 +516,7 @@ class photo extends zophTable {
      * @param string type of image to return (thumb, mid, or empty for full)
      * @return string full path.
      */
-    public function getFilePath($type=null) {
+    public function getFilePath($type = null) {
         $image_path = conf::get("path.images") . DIRECTORY_SEPARATOR .
             $this->get("path") . DIRECTORY_SEPARATOR;
 
@@ -632,14 +585,14 @@ class photo extends zophTable {
 
         if (!file_exists($file)) {
             switch ($type) {
-            case MID_PREFIX:
-                $size="width='" . MID_SIZE . "'";
-                break;
-            case THUMB_PREFIX:
-                $size="width='" . THUMB_SIZE . "'";
-                break;
-            default:
-                $size="";
+                case MID_PREFIX:
+                    $size="width='" . MID_SIZE . "'";
+                    break;
+                case THUMB_PREFIX:
+                    $size="width='" . THUMB_SIZE . "'";
+                    break;
+                default:
+                    $size="";
             }
             return new block("img", array(
                 "src"   => template::getImage("notfound.png"),
