@@ -38,6 +38,8 @@ $icons=array(
     "children"  => template::getImage("icons/folder.png"),
     "geo-photo" => template::getImage("icons/geo-photo.png"),
     "geo-place" => template::getImage("icons/geo-place.png"),
+    "pause"     => template::getImage("icons/pause.png"),
+    "play"      => template::getImage("icons/play.png"),
     "resize"    => template::getImage("icons/resize.png"),
     "unpack"    => template::getImage("icons/unpack.png"),
     "remove"    => template::getImage("icons/remove.png"),
