@@ -15,6 +15,8 @@
 
 
 var zImport=function() {
+    var categories = new Array();
+
     function startUpload(form, id, num) {
         form.style.display="none";
 
@@ -84,6 +86,38 @@ var zImport=function() {
         progressdiv.style.width=percent.toString() + "%";
     }
 
+    function httpResponseCategories(object, xml) {
+        if (xml.firstChild.tagName == "categories") {
+            makeCategorylist(xml.firstChild);
+        } else {
+            console.log("Error with XML");
+        }
+    }
+
+    function makeCategorylist(nodes) {
+        var c = nodes.childNodes;
+        var key;
+        var name;
+        for (var i=0; i < c.length; i++) {
+            if ((c[i].nodeName=="categories") || (c[i].nodeName=="category")) {
+                makeCategorylist(c[i]);
+            } else if (c[i].nodeName=="key") {
+                key=c[i].textContent;
+            } else if (c[i].nodeName=="title") {
+                name=c[i].textContent;
+            }
+
+            if (typeof name != "undefined" && typeof key != "undefined") {
+                categories.push({ name: name, key: parseInt(key,10)});
+            }
+        }
+    }
+
+    function getCategories() {
+        XML.getData("categories", "");
+        zImport.getThumbs(false);
+    }
+
     function getThumbs(notimer) {
         var http=new XMLHttpRequest();
         http.open("GET", "getxmldata.php?object=import_thumbs", true);
@@ -115,15 +149,11 @@ var zImport=function() {
                         md5=null;
                         status=null;
                         icon=null;
+                        var subjects=Array();
                         for(var c=0; c<files[i].childNodes.length; c++) {
                             tag=files[i].childNodes[c];
                             content=null;
-                            if(tag.textContent) {
-                                content=tag.textContent;
-                            } else {
-                                // And again, M$ is to dumb to follow simple standards
-                                content=tag.text;
-                            }
+                            content=tag.textContent;
                             switch(tag.nodeName) {
                             case "md5": 
                                 md5=content;
@@ -135,6 +165,12 @@ var zImport=function() {
                             case "icon":
                                 icon=content;
                                 break;
+                            case "subjects":
+                                for (var s=0; s<files[i].childNodes[c].childNodes.length; s++) {
+                                    var subject = files[i].childNodes[c].childNodes[s].textContent;
+                                    subjects.push(subject);
+                                }
+                                break;
                             }
                         }
                         deleteli=document.createElement("li");
@@ -222,10 +258,31 @@ var zImport=function() {
                                 imgsrc="";
                                 break;
                             }
+                            var categoryul=document.createElement("ul");
+                            categoryul.className="categories";
+                            var cat = 0;
+                            for (var subject in subjects) {
+                                var categoryli=createNode("li", subjects[subject]);
+                                category = categories.filter(cat => cat.name.toLowerCase() == subjects[subject].toLowerCase() );
+                                if (category.length == 0) {
+                                    categoryli.className="unknown";
+                                } else {
+                                    var input=document.createElement("input");
+                                    input.setAttribute("type", "hidden");
+                                    input.setAttribute("id", "cat_" + md5 + "[" + cat + "]");
+                                    input.value = category[0].key;
+                                    div.appendChild(input);
+                                    cat++;
+                                }
+                                categoryul.appendChild(categoryli);
+                            }
+
                             img.setAttribute("src", imgsrc);
                             div.appendChild(actionlinks);
                             div.appendChild(img);
                             div.appendChild(filename);
+                            div.appendChild(categoryul);
+
                             thumbs.appendChild(div);
                         }
                     }
@@ -388,6 +445,22 @@ var zImport=function() {
                 cb=images[i].name.split("_");
                 input.value=cb[1];
 
+                var counter = 0
+                while ( counter != -1) {
+                    var category = document.getElementById("cat_" + cb[1] + "[" + counter + "]");
+                    if (category && category.className != "unknown" ) {
+                        var catinput=document.createElement("input");
+
+                        catinput.name="_category_" + cb[1] + "["  + counter + "]";
+                        catinput.value = category.value;
+                        fieldset.appendChild(catinput);
+                        counter++;
+                    } else {
+                        counter = -1;
+                    }
+
+                }
+
                 fieldset.appendChild(input);
                 toImport++;
             }
@@ -421,6 +494,7 @@ var zImport=function() {
 
     return {
         getThumbs:getThumbs,
+        getCategories:getCategories,
         showThumbs:showThumbs,
         startUpload:startUpload,
         deleteSelected:deleteSelected,
@@ -430,6 +504,7 @@ var zImport=function() {
         deleteIframe:deleteIframe,
         doAction:doAction,
         httpResponse:httpResponse,
+        httpResponseCategories:httpResponseCategories,
         processDone:processDone,
         importPhotos:importPhotos,
         createPreviewDiv:createPreviewDiv,
@@ -438,11 +513,5 @@ var zImport=function() {
 }();
 
 if(window == top) {
-    if(window.addEventListener) {
-        window.addEventListener("load",function(){ zImport.getThumbs(false); },false);
-    } else {
-        // The clowns at M$ had to invent their own "standard"... again.
-        window.attachEvent("onload", function(){ zImport.getThumbs(false); });
-    }
-
+    window.addEventListener("load",function(){ zImport.getCategories(); },false);
 }
