@@ -53,18 +53,20 @@ if (!$_dir)   { $_dir = conf::get("interface.sort.dir"); }
 $cells = $_cols * $_rows;
 $offset = $_off;
 
-// remove photo from lightbox
-$photo_id = getvar("_photo_id");
-if ($user->get("lightbox_id") && $photo_id) {
-    $photo = new photo($photo_id);
-    $photo->removeFrom(new album($user->get("lightbox_id")));
-}
+$name = "Photos";
 
-$album_id = getvar("album_id");
-if ($album_id && $user->get("lightbox_id") &&
-    $album_id == $user->get("lightbox_id")) {
+$lightbox = $user->getLightbox();
+if ($lightbox) {
+    if ($request["album_id"] == $lightbox->getId()) {
+        $name = "Lightbox";
+    }
 
-    $lightbox = true;
+    $lbPhotos = array_map(
+        function($photo) {
+            return $photo->getId();
+        }, $lightbox->getPhotos());
+} else {
+    $lbPhotos = array();
 }
 
 $photoCollection = collection::createFromRequest(request::create());
@@ -79,7 +81,6 @@ if ($photoCount) {
 
     $num = min($cells, $displayCount);
 
-    $name = isset($lightbox) ? "Lightbox" : "Photos";
 
     $title = sprintf(translate("$name (Page %s/%s)", 0), $currentPage, $pageCount);
     $title_bar = sprintf(translate("photos %s to %s of %s"),
@@ -108,12 +109,11 @@ unset($vars["_crumb"]);
 $qs="";
 if (!empty($vars)) {
     $qs=http_build_query($vars);
-    $qs .= "&amp;";
 }
 
 if ($_action=translate("search")) {
     ?>
-    <li><a href="search.php?<?php echo $qs ?>_action=new">
+    <li><a href="search.php?<?php echo $qs ?>&amp;_action=new">
         <?php echo translate("save search") ?></a></li>
     <?php
 }
@@ -199,11 +199,11 @@ if ($displayCount <= 0) {
                 update_query_string($vars, "_off", $photoOffset, $ignore)) . "\n";
         }
 
-        if (!empty($lightbox)) {
+        if (array_search($photo->getId(), $lbPhotos) !== false) {
+            $_qs = $request->getEncodedQueryString();
             ?>
             <ul class="actionlink">
-              <li><a href="photos.php?<?php echo update_query_string($vars, "_photo_id",
-                $photo->getId(), $ignore) ?>">x</a></li>
+              <li><a href="photo.php?_action=unlightbox&photo_id=<?= $photo->getId() ?>&_qs=<?= $_qs ?>">x</a></li>
             </ul>
             <?php
         }
