@@ -204,6 +204,10 @@ ul.list {
     list-style: none;
 }
 
+ul.list > li {
+    padding: 1px;
+}
+
 ul.list > li:nth-child(2n) {
     background-color: <?= colorScheme::getColor("title_bg_color") ?>;
 }
@@ -1245,6 +1249,43 @@ div.main:fullscreen {
     padding: 0;
 }
 
+nav.slideshow {
+    position: relative;
+    top: -75px;
+    width: 100%;
+    height: 100%;
+    margin: 0 auto;
+    overflow: hidden;
+    display: flex;
+    flex-direction: row;
+    overflow: hidden;
+}
+
+nav.slideshow #butPrev,
+nav.slideshow #butNext,
+nav.slideshow #butPause {
+    flex: initial;
+    width: 20%;
+    height: <?= MID_SIZE ?>px;
+    margin: 10px;
+    opacity: 0;
+    z-index: 50;
+    background-repeat: no-repeat;
+    background-position: center;
+}
+
+nav.slideshow #butPrev {
+    background-image: url(<?= template::getImage("icons/prev.png") ?>);
+}
+nav.slideshow #butNext {
+    background-image: url(<?= template::getImage("icons/next.png") ?>);
+
+}
+nav.slideshow #butPause {
+    background-image: url(<?= template::getImage("icons/pause.png") ?>);
+    flex: auto;
+}
+
 img#butFullscreen {
     position: relative;
     float: right;
@@ -1253,9 +1294,12 @@ img#butFullscreen {
     height: 64px;
     background-image: url(<?= template::getImage("icons/fullscreen.png") ?>);
     opacity: 0.1;
-    z-index: 50;
+    z-index: 55;
 }
 
+nav.slideshow #butPrev:hover,
+nav.slideshow #butNext:hover,
+nav.slideshow #butPause:hover,
 img#butFullscreen:hover {
     opacity: 1;
 }
@@ -1264,19 +1308,38 @@ div.main:fullscreen img#butFullscreen {
     background-image: url(<?= template::getImage("icons/nofullscreen.png") ?>);
 }
 
-img.photo {
+div.photoframe {
     position: relative;
-    top: -75px;
     width: 100%;
     max-width: 100%;
     max-height: 65vh;
+    overflow: hidden;
+    clear: both;
+}
+
+img.photo {
+    position: absolute;
+    top: 0px;
+    width: 100%;
+    max-width: 100%;
+    max-height: 100%;
     object-fit: scale-down;
     margin: 0 auto;
     overflow: hidden;
 }
 
+div.main:fullscreen div.photoframe,
 div.main:fullscreen img.photo {
+    position: absolute;
     max-height: 100%;
+    height: 100%;
+}
+
+div.main:fullscreen #butPrev,
+div.main:fullscreen #butNext,
+div.main:fullscreen #butPause {
+    height: 100%;
+
 }
 
 div.slide-annotate {
@@ -2180,7 +2243,9 @@ div.import_thumbs {
 }
 
 div.import_thumbs div.thumbnail {
-    height: <?= THUMB_SIZE + 30 ?>px;
+    min-height: <?= THUMB_SIZE + 30 ?>px;
+    height: auto;
+    overflow: hidden;
 }
 
 div.import_thumbs img {
@@ -2189,6 +2254,23 @@ div.import_thumbs img {
     margin: auto;
 }
 
+div.import_thumbs ul.categories {
+    list-style: none;
+}
+
+div.import_thumbs ul.categories li {
+    display: block;
+    border: 1px solid #dddddd;
+    border-radius: 3px;
+    color: #777777;
+    font-size: xx-small;
+    margin: 2px;
+}
+
+div.import_thumbs ul.categories li.unknown {
+    background: #ffbbbb;
+}
+
 div.import textarea {
     width: 60%;
 }
